"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElasticsearchLoggerService = void 0;
const elasticsearch_1 = require("@elastic/elasticsearch");
const common_1 = require("@nestjs/common");
const ElasticsearchLoggerOptions_1 = require("./ElasticsearchLoggerOptions");
const os = require("os");
const ElasticsearchLoggerUtilities_1 = require("./ElasticsearchLoggerUtilities");
let ElasticsearchLoggerService = class ElasticsearchLoggerService {
    constructor(options) {
        this.options = options;
        this.client = new elasticsearch_1.Client(options.elasticsearchClientOptions);
    }
    async createIndexIfNotExists(index, body) {
        const result = await this.client.indices.exists({ index });
        if (result.statusCode !== 200) {
            await this.client.indices.create({
                index,
                body: body || {
                    mappings: {
                        properties: {
                            date: {
                                type: 'date'
                            },
                            hostname: { type: 'text' },
                            level: { type: 'keyword' },
                            body: { type: 'nested' }
                        }
                    }
                }
            });
        }
    }
    async log(level, message, indice) {
        if (!!indice) {
            indice = ElasticsearchLoggerUtilities_1.ElasticsearchLoggerUtilities.getRollingIndex(this.options.indexPrefix, this.options.rollingOffsetMode);
        }
        await this.createIndexIfNotExists(indice);
        const result = await this.client.index({
            index: indice,
            body: {
                date: new Date(),
                hostname: os.hostname(),
                level,
                body: message
            }
        });
        if (this.options.stdout) {
            console.log(`[${this.options.name}] ${JSON.stringify(message)}`);
        }
        return result.body._id;
    }
    async raw(message, indice) {
        if (!!indice) {
            indice = ElasticsearchLoggerUtilities_1.ElasticsearchLoggerUtilities.getRollingIndex(this.options.indexPrefix, this.options.rollingOffsetMode);
        }
        await this.createIndexIfNotExists(indice);
        const result = await this.client.index({
            index: indice,
            body: message
        });
        if (this.options.stdout) {
            console.log(`[${this.options.name}] ${JSON.stringify(message)}`);
        }
        return result.body._id;
    }
    async info(message, indice) {
        return this.log('info', message, indice);
    }
    async error(message, indice) {
        return this.log('error', message, indice);
    }
    async debug(message, indice) {
        return this.log('debug', message, indice);
    }
    async warning(message, indice) {
        return this.log('warning', message, indice);
    }
    async trace(message, indice) {
        return this.log('trace', message, indice);
    }
    async search(obj) {
        return this.client.search(obj);
    }
};
ElasticsearchLoggerService = __decorate([
    __param(0, common_1.Inject('CONFIG_OPTIONS')),
    __metadata("design:paramtypes", [ElasticsearchLoggerOptions_1.ElasticsearchLoggerOptions])
], ElasticsearchLoggerService);
exports.ElasticsearchLoggerService = ElasticsearchLoggerService;
//# sourceMappingURL=ElasticsearchLoggerService.js.map